KVXOPT
======

This package is a fork from CVXOPT including more SuiteSparse functions and KLU
sparse matrix solver.


* [Website](https://sanurielf.github.io/kvxopt/)
* [Documentation](https://sanurielf.github.io/kvxopt/userguide/index.html)



Release info
------------

[![License](https://img.shields.io/badge/license-GPL3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0.en.html) 
[![GitHub release](https://img.shields.io/github/release/sanurielf/kvxopt.svg)](https://github.com/sanurielf/kvxopt/releases/latest)
[![PyPI](https://img.shields.io/pypi/v/kvxopt.svg)](https://pypi.python.org/pypi/kvxopt)


Related projects
----------------

* [Original CVXOPT package](https://github.com/cvxopt/cvxopt)


Build status
------------


|             | [master](https://github.com/sanurielf/cvxopt/tree/master) |
|-------------|--------|
| Linux | [![Linux build](https://github.com/sanurielf/kvxopt/workflows/Linux%20build/badge.svg?branch=master)](https://github.com/sanurielf/kvxopt/actions)| 
| MacOs | [![macOS build](https://github.com/sanurielf/kvxopt/workflows/macOS%20build/badge.svg?branch=master)](https://github.com/sanurielf/kvxopt/actions)| 
| Windows (MSVC)| [![Windows build with MSVC](https://github.com/sanurielf/kvxopt/workflows/Windows%20build%20with%20MSVC/badge.svg?branch=master)](https://github.com/sanurielf/kvxopt/actions)| 
| Windows (CP27 Mingw)| [![Windows build 2.7 with MINGW](https://github.com/sanurielf/kvxopt/workflows/Windows%20build%202.7%20with%20MINGW/badge.svg?branch=master)](https://github.com/sanurielf/kvxopt/actions)| 
| Coveralls   |  [![Coverage Status](https://coveralls.io/repos/github/sanurielf/cvxopt/badge.svg?branch=master)](https://coveralls.io/github/sanurielf/cvxopt?branch=master)   |
| Readthedocs | [![RTFD Status](https://readthedocs.org/projects/cvxopt/badge/?version=latest)](http://cvxopt.readthedocs.io/en/latest/?badge=latest) |
